# This program is an example script that demonstrates how to use the event file reader dll. It comes with 2 dlls: the
# dll that reads the data (Event_File_Reader_7_2.dll) and the wrapper dll (Event_File_Reader_Dll_UM.dll).
# This example demonstrates how to load an event log file, display the header and the number of records in the file,
# retrieve a record from the file, and check for errors.

#N.B. Event_File_Reader_7_2.dll must be in the same folder as your python.exe

import ctypes
import sys

#User settings
wrapperDll = 'C:\\Event_File_Reader_Dll_UM.dll' # enter the full or relative path of the wrapper dll

maxCharactersInFile = 260 #constant, do not change this value

# for flat file format:
#numberOfFiles = 1 #flat file format has only 1 event log file
#fileNames = ((ctypes.c_char * maxCharactersInFile) * numberOfFiles)() #setting up pointer to the string array which will hold the record information
#fileNames[0] = ctypes.create_string_buffer("C:\\EVENTLOG.NLE".encode('utf-8'), maxCharactersInFile)
#end of flat file format

# for block file format
numberOfFiles = 15
fileNames = ((ctypes.c_char * maxCharactersInFile) * numberOfFiles)() #setting up pointer to the string array which will hold the record information
for i in range(numberOfFiles):
    fileNameString = "G:\\NEUR" +  str(i).rjust(4, '0') + ".DF1"
    fileNames[i] = ctypes.create_string_buffer(fileNameString.encode('utf-8'), maxCharactersInFile)
# end of block file format


recordToRetrieve = 10 # the index of the record to retrieve

# Create buffers to be used by the DLL. Do not modify this section
stringLength = 512 # strings will be a maximum of 512 characters. 
numberOfFieldsInRecord = 6 #each record has 6 fields.

errorString = ctypes.create_string_buffer(stringLength)

# Load wrapper DLL
EventFileReaderDll = ctypes.cdll.LoadLibrary(wrapperDll)

# Load event log file
maximumTimeToRunS = 10;
EventFileReaderDll.OneMillion();
error = EventFileReaderDll.LoadFiles(fileNames, numberOfFiles, maximumTimeToRunS)
if (error == 0): # file loaded successfully
    print("Files were loaded successfully\n")
else: # if LoadFile returned an error - if error code is zero, the function was successful
    EventFileReaderDll.GetErrorAsString(error, ctypes.addressof(errorString)) # return a string containing error message
    print(errorString.value.decode('utf-8')) # print the error message
    sys.exit()

### Get header - only for flat file format
#headerString = ctypes.create_string_buffer(stringLength)
#error = EventFileReaderDll.GetHeader(ctypes.addressof(headerString))

#if (error != 0):
#     EventFileReaderDll.GetErrorAsString(error,ctypes.addressof(errorString))  # input pointer to string which will store error message
#     print(errorString.value.decode('utf-8'))  # print the error message
#     sys.exit()

#print(headerString.value.decode('utf-8')) #only in flat file format
#end get header

# Get number of records in file
numberOfRecordsInFile = ctypes.c_int()
error = EventFileReaderDll.GetNumberOfRecords(ctypes.byref(numberOfRecordsInFile)) # argument is pointer to an int which will store the number of records in the file
if (error != 0):
    EventFileReaderDll.GetErrorAsString(error, ctypes.addressof(errorString)) # input pointer to string which will store error message
    print(errorString.value.decode('utf-8')) # print the error message
    sys.exit()

print("There are %d records in this file" %int(numberOfRecordsInFile.value))

# Retrieve a particular record from the file
myRecord = ((ctypes.c_char * stringLength) * numberOfFieldsInRecord)() #setting up pointer to the string array which will hold the record information
error = EventFileReaderDll.GetIndexedRecord(recordToRetrieve, myRecord) #retrieve record
if (error != 0): #if failed to retrieve record
    EventFileReaderDll.GetErrorAsString(error, ctypes.addressof(errorString))  # return a string containing error message
    print((errorString.value))  # print the error message
    sys.exit()

print ("Event number: %s\nEvent type: %s\nTimestamp: %s\nTime (ms from midnight): %s\nTime source: %s\nDetails: %s\n"
       %(float(myRecord[0].value), myRecord[1].value.decode('utf-8'), myRecord[2].value.decode('utf-8'), float(myRecord[3].value),
         myRecord[4].value.decode('utf-8'), myRecord[5].value.decode('utf-8'))) #print values in record

del wrapperDll
